import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect } from 'react';
import { Editor as MonacoEditor, loader } from '@monaco-editor/react';
import { registerDolphinDBLanguage } from '../index.js';
import { DEFAULT_SETTINGS } from './default-settings.js';
import useIsUnmounted from './use-is-unmounted.js';
let monacoInitialized = false;
let initMonacoPromise = null;
export function MonacoDolphinDBEditor({ onMonacoInit, beforeMonacoInit, onMonacoInitFailed, onMount, options, dolphinDBLanguageOptions, ...restProps }) {
    const isUnmountedRef = useIsUnmounted();
    useEffect(() => {
        (async () => {
            function setInitMonacoPromiseThenAndCatch(p) {
                p.then((monaco) => {
                    if (!isUnmountedRef.current) {
                        onMonacoInit?.(monaco);
                    }
                }).catch((err) => {
                    onMonacoInitFailed?.(err);
                });
            }
            // 已完成初始化
            if (monacoInitialized) {
                return;
            }
            // 正在初始化
            if (initMonacoPromise) {
                setInitMonacoPromiseThenAndCatch(initMonacoPromise);
                return;
            }
            // 未初始化
            initMonacoPromise = (async () => {
                await beforeMonacoInit?.();
                const monaco = await loader.init();
                await registerDolphinDBLanguage(monaco, dolphinDBLanguageOptions);
                await document.fonts.ready;
                monacoInitialized = true;
                initMonacoPromise = null;
                return monaco;
            })();
            setInitMonacoPromiseThenAndCatch(initMonacoPromise);
        })();
    }, []);
    return (_jsx(MonacoEditor, { defaultLanguage: "dolphindb", language: "dolphindb", options: {
            ...DEFAULT_SETTINGS,
            ...options,
        }, onMount: (editor, monaco) => {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            editor.getContribution('editor.contrib.suggestController').widget.value._setDetailsVisible(true);
            onMount?.(editor, monaco);
        }, ...restProps }));
}
//# sourceMappingURL=index.js.map